@@ -1,8 +1,9 @@
+import requests.exceptions
 from requests.utils import dict_from_cookiejar
 
 
-def get_api_response_data(response):
-    return {
+def get_api_response_data(response, start_time, end_time):
+    response_data = {
         "status_code": response.status_code,
         "text": response.text,
         "content": response.content,
@@ -14,5 +15,15 @@ def get_api_response_data(response):
         "request_time_sec": response.elapsed.total_seconds(),
         "request_method": response.request.method,
         "request_url": response.request.url,
-        "request_body": response.request.body
+        "request_body": response.request.body,
+        "start_time": start_time,
+        "end_time": end_time
     }
+    try:
+        if response_data.get("status_code") == 200:
+            response_data.update({"json": response.json()})
+        else:
+            pass
+    except requests.exceptions.JSONDecodeError:
+        response_data.update({"json": "can't get json"})
+    return response_data
